# generated by datamodel-codegen:
#   filename:  sftp-composer.spec.json
#   timestamp: 2021-05-26T09:43:37+00:00

from __future__ import annotations

from typing import List, Optional

from pydantic import BaseModel


class DirectoryMapping(BaseModel):
    UserPath: Optional[str] = None
    BucketPath: Optional[str] = None


class SftpComposer(BaseModel):
    HomeDirectoryDetails: Optional[List[DirectoryMapping]] = None
    PublicKeys: Optional[List[str]] = None
    Role: Optional[str] = None



#!/usr/bin/env python

"""Tests for `sftp_composer` package."""

import pytest

from sftp_composer.sftp_composer import render


@pytest.fixture()
def valid_content():
    return {
        "HomeDirectoryDetails": [
            {"UserPath": "/ingest-crac", "BucketPath": "/ingest-crac"},
            {"UserPath": "/ingest-disposals", "BucketPath": "/ingest-disposals"},
            {"UserPath": "/ingest-recon", "BucketPath": "/ingest-recon"},
            {"UserPath": "/ingest-movements", "BucketPath": "/ingest-movements"},
            {"UserPath": "/ingest-issues", "BucketPath": "/ingest-issues"},
            {"UserPath": "/ingest-shrinkage", "BucketPath": "/ingest-shrinkage"},
        ],
        "PublicKeys": [
            "ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDq",
            "ssh-rsa AAAAB3NzaC1yc2EAAAABIwAAAQEAwAQJ",
        ],
        "Role": "arn:aws:iam::012345567890:role/sftp-user",
    }


def test_main(valid_content):
    template = render(valid_content)
    print(template.to_json())



#!/usr/bin/env python
#  -*- coding: utf-8 -*-
# SPDX-License-Identifier: MPL-2.0
# Copyright 2020-2021 John Mille<john@compose-x.io>


"""Main module."""

import yaml
from os import path
from json import dumps
from .model import SftpComposer, DirectoryMapping
from troposphere import Template, Parameter, Output, Sub
from troposphere.secretsmanager import Secret

try:
    from yaml import Loader
except ImportError:
    from yaml import CLoader as Loader


def import_file_content(file_path):
    """
    Function to read input file and return YAML parsed content
    :param file_path:
    :return:
    """
    with open(path.abspath(file_path), "r") as file_fd:
        content = file_fd.read()
    return yaml.load(content, Loader=Loader)


def render_bucket_paths(secret_directories):
    """
    Function to render the buckets and user directory mapping needed by AWS SFTP in the secret

    :param list<DirectoryMapping> secret_directories:
    :return:
    """
    sftp_list = []
    for config in secret_directories:
        sftp_list.append({"Entry": config["UserPath"], "Target": config["BucketPath"]})
    return sftp_list


def render(content_input):
    """
    Render the CFN template for the SFTP mapping for secrets manager for a given input

    :param dict content_input:
    :return: The CFN troposphere template
    """
    content = SftpComposer.parse_obj(content_input)
    secret_content = content.dict()
    secret_mappings = render_bucket_paths(secret_content["HomeDirectoryDetails"])
    secret_content["HomeDirectoryDetails"] = secret_mappings
    if "PublicKeys" in secret_content.keys() and not secret_content["PublicKeys"]:
        del secret_content["PublicKeys"]
    template = Template("Template for SFTP user")
    username = Parameter("Username", Type="String")
    secret = Secret(
        "SFTPUserSecret",
        Description="SFTP User secret with directory and S3 bucket mappings",
        SecretString=dumps(secret_content),
        Name=Sub(f"SFTP/${{{username.title}}}"),
    )
    template.add_parameter(username)
    template.add_resource(secret)
    return template



#!/usr/bin/env python
#  -*- coding: utf-8 -*-
# SPDX-License-Identifier: MPL-2.0
# Copyright 2020-2021 John Mille<john@compose-x.io>


"""Console script for sftp_composer."""
import argparse
import sys


from src.sftp_composer.sftp_composer import render, import_file_content


def main():
    """Console script for sftp_composer."""
    parser = argparse.ArgumentParser()
    parser.add_argument("-f", "--file-path", type=str, required=True)
    parser.add_argument("_", nargs="*")
    args = parser.parse_args()

    print("Arguments: " + str(args._))
    print("Replace this message by putting your code into " "sftp_composer.cli.main")
    content = import_file_content(args.file_path)
    template = render(content)
    print(template.to_json())
    return 0


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover



#!/usr/bin/env python
#  -*- coding: utf-8 -*-
# SPDX-License-Identifier: MPL-2.0
# Copyright 2020-2021 John Mille<john@compose-x.io>

"""Top-level package for AWS SFTP Composer."""

__author__ = """John Preston"""
__email__ = "john@compose-x.io"
__version__ = "0.0.1"



#!/usr/bin/env python
#  -*- coding: utf-8 -*-
# SPDX-License-Identifier: MPL-2.0
# Copyright 2021 John Mille<john@compose-x.io>

"""The setup script for SFTP Composer"""

import os
import re
from setuptools import setup, find_packages

DIR_HERE = os.path.abspath(os.path.dirname(__file__))
# REMOVE UNSUPPORTED RST syntax
REF_REGX = re.compile(r"(\:ref\:)")

try:
    with open(f"{DIR_HERE}/README.rst", encoding="utf-8") as readme_file:
        readme = readme_file.read()
        readme = REF_REGX.sub("", readme)
except FileNotFoundError:
    readme = "ECS ComposeX"

try:
    with open(f"{DIR_HERE}/HISTORY.rst", encoding="utf-8") as history_file:
        history = history_file.read()
except FileNotFoundError:
    history = "Latest packaged version."

requirements = []
with open(f"{DIR_HERE}/requirements.txt", "r") as req_fd:
    for line in req_fd:
        requirements.append(line.strip())

test_requirements = []
try:
    with open(f"{DIR_HERE}/requirements_dev.txt", "r") as req_fd:
        for line in req_fd:
            test_requirements.append(line.strip())
except FileNotFoundError:
    print("Failed to load dev requirements. Skipping")

setup_requirements = []

setup(
    author="John Preston",
    author_email="john@compose-x.io",
    python_requires=">=3.7",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    description="Render Secrets for AWS SFTP integration",
    entry_points={
        "console_scripts": [
            "sftp_composer=sftp_composer.cli:main",
        ],
    },
    install_requires=requirements,
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="sftp_composer",
    name="sftp_composer",
    packages=find_packages(include=["sftp_composer", "sftp_composer.*"], where="src"),
    package_dir={"": "src"},
    setup_requires=setup_requirements,
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/johnpreston/sftp_composer",
    version="0.0.1",
    zip_safe=False,
)
